@@ -3,7 +3,15 @@
 
 #include <zorp/code.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 ZCode *z_code_gzip_encode_new(gint bufsize, gint compress_level);
 ZCode *z_code_gzip_decode_new(gint bufsize);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
