@@ -5,13 +5,12 @@
  * under the terms of Zorp Professional Firewall System EULA located
  * on the Zorp installation CD.
  *
- * $Id: zorplib.h,v 1.10 2003/04/08 13:32:29 sasa Exp $
- *
  ***************************************************************************/
 #ifndef ZORPLIB_RANDOM_H_INCLUDED
 #define ZORPLIB_RANDOM_H_INCLUDED
 
 #include <glib.h>
+#include <vector>
 
 #ifdef __cplusplus
 extern "C" {
@@ -40,4 +39,6 @@ z_random_sequence_get_bounded(ZRandomStrength strength,
 }
 #endif
 
+std::vector<unsigned int> z_random_sequence_create(const unsigned int len, const unsigned int min);
+
 #endif
