@@ -1,8 +1,9 @@
 /***************************************************************************
  *
- * COPYRIGHTHERE
- *
- * $Id: streamfd.h,v 1.8 2003/05/14 16:40:23 bazsi Exp $
+ * This file is covered by a dual licence. You can choose whether you
+ * want to use it according to the terms of the GNU GPL version 2, or
+ * under the terms of Zorp Professional Firewall System EULA located
+ * on the Zorp installation CD.
  *
  ***************************************************************************/
 
@@ -17,7 +18,7 @@
 extern "C" {
 #endif
 
-ZStream *z_stream_blob_new(ZBlob *blob, gchar *name);
+ZStream *z_stream_blob_new(ZBlob *blob, const gchar *name);
 
 #ifdef __cplusplus
 }
